CaseCommand

Enum CaseCommand 

pub enum CaseCommand {
Show 13 variants Create(CaseCreateArgs), List, Show { case_ref: String, }, Add { case_ref: String, message_id: String, summary: Option<String>, reason: Option<String>, }, Move { case_ref: String, group: String, }, Rename { case_ref: String, name: String, reason: Option<String>, }, Notes { action: CaseNotesAction, }, Archive { case_ref: String, reason: Option<String>, }, Reopen { case_ref: String, reason: Option<String>, }, Tag { case_ref: String, tag: String, reason: Option<String>, }, Untag { case_ref: String, tag: String, reason: Option<String>, }, Draft { action: CaseDraftAction, }, Merge { case_ref: String, other_case_ref: String, reason: Option<String>, },
}

Variants



Create(CaseCreateArgs)

Create a new case and return its stable UID/ref.



List

List compact active case locators.



Show

Show a case’s case.md (active or archived) without changing workspace state.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.



Add

Add a message to this existing case.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

message_id: String

Message id to add.

summary: Option<String>

Short summary for this message in the case.

reason: Option<String>

Why this message belongs in this case; required by default.



Move

Move this case to another group.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

group: String

Destination group.



Rename

Rename this active case’s human-readable name without changing its UID.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

name: String

New human-readable case name.

reason: Option<String>

Why this name better represents the case; required by default.



Notes

Show or edit active case notes.

Fields



Archive

Archive this active case.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

reason: Option<String>

Why this case is ready to archive; required by default.



Reopen

Reopen this case as active work without changing its tags.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

reason: Option<String>

Why this case should be reopened; required by default.



Tag

Add a case organization tag.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

tag: String

Case organization tag.

reason: Option<String>

Why this tag is useful; required by default.



Untag

Remove a case organization tag.

Fields

case_ref: String

Case ref: cYYYYMMDDNNN or cYYYYMMDDNNN-any-suffix.

tag: String

Case organization tag.

reason: Option<String>

Why this tag should be removed; required by default.



Draft

Create, edit, validate, queue, or remove local case drafts.

Fields



Merge

Merge another case into this case.

Fields

case_ref: String

Primary case ref.

other_case_ref: String

Case ref to merge into the primary case.

reason: Option<String>

Why these cases should be merged; required by default.