pub enum MessageAction {
Show {
message_id: String,
},
Spam {
message_id: String,
reason: Option<String>,
},
Trash {
message_id: String,
reason: Option<String>,
},
Restore {
message_id: String,
reason: Option<String>,
},
Attachment {
action: MessageAttachmentAction,
},
}Variants
Show
Show the full local message metadata, body text, and attachment metadata.
Spam
Mark junk/phishing/malware/suspicious mail locally, show it under spam/, and queue a Junk move.
Fields
Trash
Explicitly discard this message locally, show it under trash/, and queue a Trash move.
Fields
Restore
Restore a message from spam, trash, or direct archive back to triage.
Fields
Attachment
Fetch an attachment for this message.
Fields

action: MessageAttachmentActionTrait Implementations
Sourceimpl Debug for MessageAction
impl Debug for MessageAction
Sourceimpl FromArgMatches for MessageAction
impl FromArgMatches for MessageAction
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for MessageAction
impl Subcommand for MessageAction
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for MessageAction
impl RefUnwindSafe for MessageAction
impl Send for MessageAction
impl Sync for MessageAction
impl Unpin for MessageAction
impl UnsafeUnpin for MessageAction
impl UnwindSafe for MessageAction