pub struct ArchiveMessageCreateArgs {
pub name: String,
pub message: Option<String>,
pub summary: Option<String>,
pub reason: Option<String>,
}Fields
name: StringHuman-readable archive category name used in metadata and the directory suffix.
message: Option<String>Optional message to immediately file into the new archive category.
summary: Option<String>Required when –message is supplied.
reason: Option<String>Why this archive category is being created.