pub struct DraftFrontmatter {
pub kind: Option<String>,
pub case_uid: String,
pub send_intent: Option<String>,
pub reply_to_message_id: Option<String>,
pub identity: Option<String>,
pub subject: Option<String>,
pub to: Vec<String>,
pub cc: Vec<String>,
pub attachments: Vec<String>,
}Expand description
Frontmatter of an agent-authored drafts/*.md. Shared by draft validation
and outbound message building so both agree on one schema.
Fields
kind: Option<String>case_uid: Stringsend_intent: Option<String>reply_to_message_id: Option<String>identity: Option<String>subject: Option<String>to: Vec<String>cc: Vec<String>attachments: Vec<String>Trait Implementations
Sourceimpl Clone for DraftFrontmatter
impl Clone for DraftFrontmatter
Sourcefn clone(&self) -> DraftFrontmatter
fn clone(&self) -> DraftFrontmatter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DraftFrontmatter
impl Debug for DraftFrontmatter
Sourceimpl Default for DraftFrontmatter
impl Default for DraftFrontmatter
Sourcefn default() -> DraftFrontmatter
fn default() -> DraftFrontmatter
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DraftFrontmatter
impl<'de> Deserialize<'de> for DraftFrontmatter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DraftFrontmatter
Sourceimpl PartialEq for DraftFrontmatter
impl PartialEq for DraftFrontmatter
Sourcefn eq(&self, other: &DraftFrontmatter) -> bool
fn eq(&self, other: &DraftFrontmatter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DraftFrontmatter
impl Serialize for DraftFrontmatter
impl StructuralPartialEq for DraftFrontmatter