Module types

Module types 

Re-exports

pub use contact::ContactFrontmatter;
pub use contact::CONTACT_KIND;

Modules

contact

Structs

ArchiveUid
AttachmentRef
CaseUid
ImapRef
MessageActionPush
MessageAuthentication
Structured view of a message’s Authentication-Results headers.
MessageCollection
MessageCollectionItem
MessageContact
Snapshot of the contact whose email set includes this message’s sender.
MessageFile
MessageId
OutboundPush
PushId
PushItem
PushLocation
PushStepState
RemoteLocation
RemoteState
RemoteSyncState
WorkspacePendingPush
WorkspacePushState
WorkspaceState

Enums

AuthAlignment
Whether the DMARC-authenticated domain lines up with the visible From domain. Unknown when there is nothing authenticated to compare against.
AuthVerdict
Result of a single email authentication mechanism (SPF / DKIM / DMARC).
MailDirection
MessagePushAction
MessageStatus
OutboundAction
PushKind
PushPayload
PushStepStatus

Constants

ARCHIVE_NOTIFICATION_SCHEMA_NAME
CASE_SCHEMA_NAME
MESSAGE_COLLECTION_SCHEMA_VERSION

Type Aliases

ArchiveMessageItem
ArchiveMessages
CaseMessages