pub struct MessageContact {
pub contact_uid: String,
pub display_name: String,
}Expand description
Snapshot of the contact whose email set includes this message’s sender.
Fields
contact_uid: Stringdisplay_name: StringTrait Implementations
Sourceimpl Clone for MessageContact
impl Clone for MessageContact
Sourcefn clone(&self) -> MessageContact
fn clone(&self) -> MessageContact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageContact
impl Debug for MessageContact
Sourceimpl<'de> Deserialize<'de> for MessageContact
impl<'de> Deserialize<'de> for MessageContact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MessageContact
Sourceimpl PartialEq for MessageContact
impl PartialEq for MessageContact
Sourcefn eq(&self, other: &MessageContact) -> bool
fn eq(&self, other: &MessageContact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MessageContact
impl Serialize for MessageContact
impl StructuralPartialEq for MessageContact