MessageFile

Struct MessageFile 

pub struct MessageFile {
Show 33 fields pub schema_name: String, pub schema_version: u64, pub message_id: String, pub rfc822_message_id: Option<String>, pub in_reply_to: Option<String>, pub references: Vec<String>, pub remote: Option<RemoteState>, pub direction: Option<String>, pub subject: Option<String>, pub from: Option<String>, pub to: Vec<String>, pub cc: Vec<String>, pub bcc: Vec<String>, pub reply_to: Vec<String>, pub sender: Option<String>, pub delivered_to: Vec<String>, pub x_original_to: Vec<String>, pub envelope_to: Vec<String>, pub list_id: Option<String>, pub mailing_list_headers: Vec<String>, pub authentication: MessageAuthentication, pub received_rfc3339: Option<String>, pub sent_rfc3339: Option<String>, pub body_text: String, pub eml_path: Option<String>, pub attachments: Vec<AttachmentRef>, pub contact: Option<MessageContact>, pub identity: Option<String>, pub identity_email: Option<String>, pub identity_match: Option<String>, pub identity_candidates: Vec<String>, pub observed_recipient_emails: Vec<String>, pub workspace: WorkspaceState,
}

Fields

schema_name: Stringschema_version: u64message_id: Stringrfc822_message_id: Option<String>in_reply_to: Option<String>references: Vec<String>remote: Option<RemoteState>direction: Option<String>subject: Option<String>from: Option<String>to: Vec<String>cc: Vec<String>bcc: Vec<String>reply_to: Vec<String>sender: Option<String>delivered_to: Vec<String>x_original_to: Vec<String>envelope_to: Vec<String>list_id: Option<String>mailing_list_headers: Vec<String>authentication: MessageAuthenticationreceived_rfc3339: Option<String>sent_rfc3339: Option<String>body_text: Stringeml_path: Option<String>attachments: Vec<AttachmentRef>contact: Option<MessageContact>

Contact association materialized from the sender address at render/materialize time. Read-only on message show; refreshed when a contact’s emails or name change, or by afmail render refresh.

identity: Option<String>identity_email: Option<String>identity_match: Option<String>identity_candidates: Vec<String>observed_recipient_emails: Vec<String>workspace: WorkspaceState