pub struct WorkspaceState {
pub status: String,
pub archive_uid: Option<String>,
pub archived_rfc3339: Option<String>,
pub origin: Option<String>,
pub remote_sync: Option<RemoteSyncState>,
pub push: Option<WorkspacePushState>,
}Fields
status: Stringarchive_uid: Option<String>archived_rfc3339: Option<String>origin: Option<String>Provenance tag for messages whose archived status comes from a remote source rather than an explicit local disposition (e.g. “imap-archive”).
remote_sync: Option<RemoteSyncState>push: Option<WorkspacePushState>Trait Implementations
Sourceimpl Clone for WorkspaceState
impl Clone for WorkspaceState
Sourcefn clone(&self) -> WorkspaceState
fn clone(&self) -> WorkspaceState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceState
impl Debug for WorkspaceState
Sourceimpl<'de> Deserialize<'de> for WorkspaceState
impl<'de> Deserialize<'de> for WorkspaceState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceState
Sourceimpl PartialEq for WorkspaceState
impl PartialEq for WorkspaceState
Sourcefn eq(&self, other: &WorkspaceState) -> bool
fn eq(&self, other: &WorkspaceState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkspaceState
impl Serialize for WorkspaceState
impl StructuralPartialEq for WorkspaceState