pub enum CaseCommand {
Show 13 variants
Create(CaseCreateArgs),
List,
Show {
case_ref: String,
},
Add {
case_ref: String,
message_id: String,
summary: Option<String>,
reason: Option<String>,
},
Move {
case_ref: String,
group: String,
},
Rename {
case_ref: String,
name: String,
reason: Option<String>,
},
Notes {
action: CaseNotesAction,
},
Archive {
case_ref: String,
reason: Option<String>,
},
Reopen {
case_ref: String,
reason: Option<String>,
},
Tag {
case_ref: String,
tag: String,
reason: Option<String>,
},
Untag {
case_ref: String,
tag: String,
reason: Option<String>,
},
Draft {
action: CaseDraftAction,
},
Merge {
case_ref: String,
other_case_ref: String,
reason: Option<String>,
},
}Variants
Create(CaseCreateArgs)
Create a new case and return its stable UID/ref.
List
List compact active case locators.
Show
Show a case’s case.md (active or archived) without changing workspace state.
Add
Add a message to this existing case.
Fields
Move
Move this case to another group.
Fields
Rename
Rename this active case’s human-readable name without changing its UID.
Fields
Notes
Show or edit active case notes.
Fields

action: CaseNotesActionArchive
Archive this active case.
Fields
Reopen
Reopen this case as active work without changing its tags.
Fields
Tag
Add a case organization tag.
Fields
Untag
Remove a case organization tag.
Fields
Draft
Create, edit, validate, queue, or remove local case drafts.
Fields

action: CaseDraftActionMerge
Merge another case into this case.