pub enum ContactCommand {
Show 13 variants
Create(ContactCreateArgs),
List {
group: Option<String>,
tag: Option<String>,
org: Option<String>,
role: Option<String>,
},
Show {
contact_ref: String,
},
Move {
contact_ref: String,
group: String,
},
Rename {
contact_ref: String,
name: String,
},
Email {
action: ContactEmailAction,
},
Phone {
action: ContactPhoneAction,
},
Tag {
contact_ref: String,
tag: String,
},
Untag {
contact_ref: String,
tag: String,
},
Notes {
action: ContactNotesAction,
},
Archive {
contact_ref: String,
reason: Option<String>,
},
Reopen {
contact_ref: String,
group: Option<String>,
reason: Option<String>,
},
Extract {
from_triage: bool,
from_case: Option<String>,
all: bool,
group: Option<String>,
},
}Variants
Create(ContactCreateArgs)
Create a new contact record.
List
List contacts, optionally filtered by group, tag, org, or role.
Fields
Show
Show a contact’s full file content.
Move
Move a contact to a different group.
Fields
Rename
Rename a contact’s display name.
Fields
Add or remove email addresses for a contact.
Fields

action: ContactEmailActionPhone
Add or remove phone numbers for a contact.
Fields

action: ContactPhoneActionTag
Add a tag to a contact.
Fields
Untag
Remove a tag from a contact.
Fields
Notes
Show or edit contact notes.
Fields

action: ContactNotesActionArchive
Archive an active contact.
Fields
Reopen
Reopen an archived contact as active.
Fields
Extract
Extract stub contacts from message senders not yet in the contact list.